<?php

/**
 * Implementiert die Einstellung  der zeitrelevante Parameter
 * @author Miguel Palmer <mp@beronet.com>
 */

include_once('/usr/www/include/SQLite2ToSQLite3.php');

class TimeConf {

	private		$m_attr;

	private		$post_attr,
			$post_checked = 0;
	
	private		$isRequestRejected = 0,
			$reasonRejected = array();

	private		$default = array(	
						'timezone_val' => array(	"+12", "+11", "+10", "+9", "+8", "+7", "+6", "+5", "+4", "+3:30", "+3", "+2", "+1", "+0","-1", "-2", "-3",
										"-3:30", "-4", "-4:30", "-5", "-5:30", "-5:45", "-6", "-7", "-8", "-9", "-9:30", "-10", "-11", "-12")
					);

	/**
	 * Constructor
	 */
	function __construct($m, $get = array(), $post = array(), $session = array()) {
		$this->m_attr = $m;

		// checking POST
		if ($post['action'] == "save") {
			unset($post['action'], $post['Apply']);

			$list_post = array('ntphost' => 'hostname', 'timezone' => 'select', 'time_from_isdn' => array('||', 'select', 'int>0'), 'summer_winter_time' => 'bool');

			$list_options_select = array( 	'timezone' 		=> $this->default['timezone_val'],
							'time_from_isdn'	=> array('no'));

			$this->post_checked = 1;
			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected, $list_options_select);

			$this->isRequestRejected = !$this->post_checked;
		}
	}
	
	/**
	 * Generates the timezone otions
	 * @return string
	 */
	function options() {
		$bc = new beroConf('root');
		$arr_text = array("(GMT -12:00) Eniwetok, Kwajalein", "(GMT -11:00) Midway Island, Samoa",
			"(GMT -10:00) Hawaii", "(GMT -9:00) Alaska", "(GMT -8:00) Pacific Time (US &amp; Canada)",
			"(GMT -7:00) Mountain Time (US &amp; Canada)", "(GMT -6:00) Central Time (US &amp; Canada), Mexico City",
			"(GMT -5:00) Eastern Time (US &amp; Canada), Bogota, Lima", "(GMT -4:00) Atlantic Time (Canada), Caracas, La Paz",
			"(GMT -3:30) Newfoundland", "(GMT -3:00) Brazil, Buenos Aires, Georgetown",
			"(GMT -2:00) Mid-Atlantic", "(GMT -1:00 hour) Azores, Cape Verde Islands",
			"(GMT) Western Europe Time, London, Lisbon, Casablanca", "(GMT +1:00) Berlin, Brussels, Copenhagen, Madrid, Paris",
			"(GMT +2:00) Kaliningrad, South Africa", "(GMT +3:00) Baghdad, Riyadh, Moscow, St. Petersburg",
			"(GMT +3:30) Tehran", "(GMT +4:00) Abu Dhabi, Muscat, Baku, Tbilisi",
			"(GMT +4:30) Kabul", "(GMT +5:00) Ekaterinburg, Islamabad, Karachi, Tashkent",
			"(GMT +5:30) Bombay, Calcutta, Madras, New Delhi", "(GMT +5:45) Kathmandu",
			"(GMT +6:00) Almaty, Dhaka, Colombo", "(GMT +7:00) Bangkok, Hanoi, Jakarta",
			"(GMT +8:00) Beijing, Perth, Singapore, Hong Kong", "(GMT +9:00) Tokyo, Seoul, Osaka, Sapporo, Yakutsk",
			"(GMT +9:30) Adelaide, Darwin", "(GMT +10:00) Eastern Australia, Guam, Vladivostok",
			"(GMT +11:00) Magadan, Solomon Islands, New Caledonia", "(GMT +12:00) Auckland, Wellington, Fiji, Kamchatka");

		$arr_val = $this->default['timezone_val'];

		$sp = $bc->get("root", "timezone");
		$options = "";
		for ($i = 0; $i < count($arr_val); $i++) {
			($arr_val[$i] == $sp) ? $selected = "selected" : $selected = "";
			$options .= "<option value='" . $arr_val[$i] . "' " . $selected . ">" . $arr_text[$i] . "</option>";
		}
		return $options;
	}

	/**
	 * Generates the options for the time from isdn dropdown menu
	 * @return string
	 */
	function ports($def = 0) {
		$ba = new beroAri();
		$options = "<option value='no'>Disabled</option>";
		$query = $ba->select("select port from isdn");
		while ($ports = $ba->fetch_array($query)) {
			if ($def == $ports['port']) {
				$options .= "<option value='" . $ports['port'] . "' selected>Port " . $ports['port'] . "</option>";
			} else {
				$options .= "<option value='" . $ports['port'] . "'>Port " . $ports['port'] . "</option>";
			}
		}
		return $options;
	}

	/**
	 * Saves the time setting to the database
	 * @param beroConf $bc
	 * @param beroAri $ba
	 * @return string
	 */
	function save($bc, $ba) {
		$ret .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
		$ntp = $bc->get("root", "gui-ntphost");
		$bc->set("root", "gui-ntphost", sqlite_escape_string($this->post_attr['ntphost']));
		$bc->set("root", "ntphost", sqlite_escape_string($this->post_attr['ntphost']));
		$bc->set("root", "timezone", sqlite_escape_string($this->post_attr['timezone']));

		if ($this->post_attr['time_from_isdn'] != "no") {
			$bc->set("root", "time_from_isdn", $this->post_attr['time_from_isdn']);
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$ret .= "<br/><div class='text-center'>" . $isgw->itpX($this->post_attr['time_from_isdn']) . "</div><br/>";
			$bc->set("root", "timezone", "0");
			$bc->set("root", "ntphost", "");
			$ba->set("summer_winter_time", "0");
			system("/bin/mount -o remount,rw /;
	 			/bin/echo \"GMT0\" > /etc/TZ;
 	 			/bin/mount -o remount,ro /;
 	 			/bin/sync;");
			$bc->set("root", "ntphost", "");
			$bc->set("root", "gui-ntphost", "");
		} else {
			//Seite beim Timeout des servers neuladen wenn der ntp host sich verändert hat
			if ($ntp != $this->post_attr['ntphost'])
				echo '<script>
                            setTimeout(function () {
                                location.href = location.href;
                            }, 500);  // just reloads the page
                        </script>';
			if ($this->post_attr['summer_winter_time'] == "1") {
				$ba->set("summer_winter_time", "1");
				system("/bin/mount -o remount,rw /;
	 				/bin/echo \"CET" . $this->post_attr['timezone'] . "CEST,M3.5.0/02:00:00,M10.5.0/03:00:00\" > /etc/TZ;
 	 				/bin/mount -o remount,ro /;
 	 				/bin/sync;");
			} else {
				$ba->set("summer_winter_time", "0");
				system("/bin/mount -o remount,rw /;
	 				/bin/echo \"GMT" . ($this->post_attr['timezone']) . "\" > /etc/TZ;
 	 				/bin/mount -o remount,ro /;
 	 				/bin/sync;");
			}
			$bc->set("root", "time_from_isdn", "no");
			$bc->set("root", "timezone", sqlite_escape_string($this->post_attr['timezone']));
			$bc->set("root", "ntphost", sqlite_escape_string($this->post_attr['ntphost']));
			$bc->set("root", "gui-ntphost", sqlite_escape_string($this->post_attr['ntphost']));

			exec("/usr/sbin/update-time");
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->itpX("no");
			$ret .= "<br/><div class='text-center'>" . Helper::getDate() . "</div><br/>";
		}
		return $ret;
	}

	/**
	 * Generates the HTML page
	 * @return string
	 */
	function display() {

		include '/usr/fallback/beroConf.php';
		require_once ('./includes/isgwtelnet.php');
		$bc = new beroConf('root');
		$ba = new beroAri();

		$name = "TIME_TITLE_DIS";
		include('./includes/header.php');
		require_once("./includes/lang.php");

		// args
		$m = $this->m_attr;
		if (!$bc->valid()) {
			$ret .= '<h3>Error:</h3><b>Failed to connect to config database!</b><br>';
			exit(0);
		}

		//Save settings
		if ($this->post_checked) {
			$ret .= $this->save($bc, $ba);
		} else if ($this->isRequestRejected) {
			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
		}

		if ($ba->get('gui_mode') == 'simple') {
			$simple_class = 'simple';
		}
		if ($ba->get("summer_winter_time") == "1" || $ba->get("summer_winter_time") == "yes") {
			$summerTime = "checked";
		}
		ob_start();
		?>

		<script>
		    function tfi(ch) {
		        if (ch != 0) {
		            document.getElementById('ntphost').style.display = 'none';
		            document.getElementById('tz').style.display = 'none';
		            document.getElementById('summer_winter').style.display = 'none';
		        } else {
		            document.getElementById('ntphost').style.display = '';
		            document.getElementById('tz').style.display = '';
		            document.getElementById('summer_winter').style.display = '';
		        }

		    }
		</script>
		<br>
		<form  name="timeform" id="timeform" class="form-horizontal" method="POST" action="">
			<input type="hidden" name="action" value="save">
			<p class="text-center lead" ><?php echo TIME_TABLE_HEADER_DIS ?></p>

			
			<?php
				$ntp_hover = "";
				$ntp_asterisk = "";
				$gui_ntp_host = $bc->get("root", "gui-ntphost");
				if (!strlen ($gui_ntp_host)) {
					$ntp_host = $bc->get("root", "ntphost");
					if (strlen ($ntp_host)) {
						$ntp_asterisk = "<span style=color:red>*</span>";
						$ntp_hover = "onmouseover='Tip(\"" . "Using default NTP: " . $ntp_host ."\"" . ")' onmouseout='UnTip()'";
					}
				}
				
			?>
			<div class='form-group' id="ntphost">
				<label  <?php echo $ntp_hover ?> for='ntphost' class='col-sm-5 control-label'><?php echo TIME_NTP_HOST_DIS . $ntp_asterisk ?></label>
				<div class='col-sm-4'>
					<input name="ntphost" <?php echo $ntp_hover ?> class="form-control input-sm" type="text" size="15" id="ntphost" value="<?php echo $gui_ntp_host ?>">
				</div>
			</div>
			
			<div class='form-group' id="tz">
				<label for='timezone' class='col-sm-5 control-label'><?php echo TIME_TIMEZONE_DIS ?></label>
				<div class='col-sm-4'>
					<select name="timezone" class="form-control input-sm" id="timezone">
						<?php echo $this->options() ?>
					</select>
				</div>
			</div>
			<div class='form-group' id="summer_winter">
				<label for='summer_winter_time' class='col-sm-5 control-label'><?php echo TIME_SUMMER_WINTER_DIS ?></label>
				<div class='col-sm-4'>
					<input type="hidden" name="summer_winter_time" id="summer_winter_time" value="0">
					<input type="checkbox" name="summer_winter_time" id="summer_winter_time" value="1" <?php echo $summerTime ?>>
				</div>
			</div>

			<div class="form-group <?php echo $simple_class ?>" >
				<label for='time_from_isdn' class='col-sm-5 control-label'><?php echo TIME_TIME_FROM_ISDN_DIS ?></label>
				<div class='col-sm-4'>
					<select name="time_from_isdn" class="form-control input-sm" id="time_from_isdn" 
							onclick="tfi(time_from_isdn.selectedIndex);">
								<?php echo $this->ports($bc->get("root", "time_from_isdn")) ?>
					</select>
				</div>
			</div>
			<br>
			<div class="text-center">
				<input type="submit" class="btn btn-default" name="Apply" value="<?php echo BUTTON_SAVE ?>">
			</div>
		</form>
		<script>
		    $("#timeform").validate({

		        rules: {
		            ntphost: {
		                checkHostname: true,
		            },
		        }
		    });
		    tfi(document.getElementById("time_from_isdn").selectedIndex);
		</script>
		<?php
		$ret .= ob_get_clean();

		return $ret;
	}

}
?>
